@@ -71,14 +71,25 @@ class mongodb(object):
 
     def login(self):
         if self.is_login:
-            if self.not_timeout()
-                return True
-            else:
-                log(f"{self}连接超时，强制重连")
-        self.conn = pymongo.MongoClient("mongodb://{host}:{port}/".format(**self.__dict__))
+            return True
+            # if self.not_timeout():
+            #     return True
+            # else:
+            #     log(f"{self} 连接超时，强制重连")
+
         if self.user and self.passwd:
-            auth = self.conn["admin"]
-            auth.authenticate(self.user, self.passwd, mechanism=self.mechanism)
+            self.conn = pymongo.MongoClient(
+                      # "mongodb://{host}:{port}/".format(**self.__dict__),
+                      host=self.host,
+                      port=self.port,
+                      username=self.user,
+                      password=self.passwd,
+                      authSource='admin',
+                      authMechanism=self.mechanism,
+                      connect=False)
+        else:
+            self.conn = pymongo.MongoClient(host=self.host, port=self.port, connect=False)
+
         self._db = self.conn[self.db]
         self._table = self._db[self.table]
         self.is_login = True
